@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = 0.1001;
+our $VERSION = 0.11;
 
 =head1 NAME
 
@@ -182,7 +182,9 @@ will now be directed to CODEREF.
 
 Longer paths are GUARANTEED to be checked first.
 
-Dies if same route is given twice.
+Dies if the same method and path combo is given again.
+Multiple methods may be given for the same path,
+e.g. when handling REST.
 
 Exactly one leading slash will be prepended no matter what you do.
 (C<path>, C</path> and C</////path> are all the same).
@@ -193,7 +195,7 @@ Exactly one leading slash will be prepended no matter what you do.
 
 =item * description - just for information, has no action on execution.
 
-=item * method - list of allowed HTTP methods - GET, POST & so on.
+=item * method - list of allowed HTTP methods. Default is [GET, POST, HEAD].
 
 =item * view - default View object for this Controller.
 Must be an object with a C<render> methods, or a CODEREF
@@ -222,16 +224,17 @@ sub route {
     # root becomes nothing (which is OK with us).
     $path =~ s#^/*#/#;
     $path =~ s#/+$##;
-    $self->_croak( "Attempting to set duplicate handler for path "
+
+    $args{method} ||= [qw[ GET POST HEAD ]];
+    $args{method} = [ $args{method} ] unless ref $args{method} eq 'ARRAY';
+
+    my @dupe = grep { exists $self->{route}{$path}{$_} } @{ $args{method} };
+    $self->_croak( "Attempting to set duplicate handler for [@dupe] "
         .( length $path ? $path : "/" ) )
-            if $self->{route}{ $path };
-
-    # reset cache
-    $self->{route_re} = undef;
-
-    my %profile;
+            if @dupe;
 
     # Do the work
+    my %profile;
     $profile{code}     = $sub;
     $profile{caller}   = [caller(0)]; # file,line
 
@@ -239,15 +242,6 @@ sub route {
     $profile{path}        = $path;
     $profile{description} = $args{description};
 
-    if ($args{method}) {
-        $args{method} = [ $args{method} ] unless ref $args{method} eq 'ARRAY';
-        my %allowed;
-        foreach (@{ $args{method} }) {
-            $allowed{ uc $_ }++;
-        };
-        $profile{allowed_methods} = \%allowed;
-    };
-
     if (my $view = $args{view}) {
         if (!ref $view) {
             $view = $self->load_view( $view );
@@ -261,7 +255,11 @@ sub route {
         $profile{view} = $view;
     };
 
-    $self->{route}{ $path } = \%profile;
+    # ready, install handler & burn cache
+    delete $self->{route_re};
+    $self->{route}{ $path }{$_} = \%profile
+        for @{ $args{method} };
+
     return $self;
 };
 
@@ -305,7 +303,8 @@ Serve static content located under $file_path.
 
 File type detection is based on extention.
 This MAY change in the future.
-Known file types are listed in %MVC::Neaf::ExtType hash. Patches welcome.
+Known file types are listed in %MVC::Neaf::X::Files::ExtType hash.
+Patches welcome.
 
 %options may include:
 
@@ -318,6 +317,8 @@ Default is 4096. Smaller values may be set, but are NOT recommended.
 in memory for cache_ttl seconds.
 B<EXPERIMENTAL>. Cache API is not yet established.
 
+=item * description - comment. The default is "Static content at $dir"
+
 =back
 
 Generally it is probably a bad idea to serve files in production
@@ -330,14 +331,21 @@ This is the intended usage.
 
 =cut
 
+my %static_options;
+$static_options{$_}++ for qw( description buffer cache_ttl );
 sub static {
     my ($self, $path, $dir, %options) = @_;
     $self = $Inst unless ref $self;
 
+    my @extra = grep { !$static_options{$_} } keys %options;
+    $self->_croak( "Unknown options @extra" )
+        if @extra;
+
     require MVC::Neaf::X::Files;
     my $xfiles = MVC::Neaf::X::Files->new( %options, root => $dir );
     return $self->route($path => $xfiles->make_handler
-        , method => ['GET', 'HEAD']);
+        , method => ['GET', 'HEAD']
+        , description => $options{description} || "Static content at $dir" );
 };
 
 =head2 pre_route( sub { ... } )
@@ -843,8 +851,7 @@ sub handle_request {
         # Lookup the rules for the given path
         $req->path =~ $self->{route_re} and $route = $self->{route}{$1}
             or die "404\n";
-        !exists $route->{allowed_methods}
-            or $route->{allowed_methods}{ $req->method }
+        $route = $route->{ $req->method }
             or die "405\n";
         $req->set_full_path( $1, $2 );
 
@@ -981,10 +988,77 @@ sub _croak {
     croak( (ref $self || $self)."->$where: $msg" );
 };
 
+=head1 MORE EXAMPLES
+
+See the examples directory in this distro or at
+L<https://github.com/dallaylaen/perl-mvc-neaf/tree/master/example>
+for complete working examples.
+These below are just code snippets.
+
+All of them are supposed to start and end with:
+
+    use strict;
+    use warnings;
+    use MVC::Neaf;
+
+    # ... snippet here
+
+    MVC::Neaf->run;
+
+=head2 Static content
+
+    MVC::Neaf->static( '/images' => "/local/images" );
+    MVC::Neaf->static( '/favicon.ico' => "/local/images/icon_32x32.png" );
+
+=head2 RESTful web-service returning JSON
+
+    MVC::Neaf->route( '/restful' => sub {
+        # ...
+    }, method => 'GET', view => 'JS' );
+
+    MVC::Neaf->route( '/restful' => sub {
+        # ...
+    }, method => 'POST', view => 'JS' );
+
+    MVC::Neaf->route( '/restful' => sub {
+        # ...
+    }, method => 'PUT', view => 'JS' );
+
+=head2 Form submission
+
+    use MVC::Neaf::X::Form;
+
+    my %profile = (
+        name => [ required => '\w+' ],
+        age  => '\d+',
+    );
+    my $validator = MVC::Neaf::X::Form->new( \%profile );
+
+    MVC::Neaf->route( '/submit' => sub {
+        my $req = shift;
+
+        my $form = $req->form( $validator );
+        if ($req->is_post and $form->is_valid) {
+            do_somethong( $form->data );
+            $req->redirect( "/result" );
+        };
+
+        return {
+            -template   => 'form.tt',
+            errors      => $form->error,
+            fill_values => $form->raw,
+        };
+    } );
+
+More examples to follow as usage (hopefuly) accumulates.
+
 =head1 BUGS
 
 Lots of them, this software is still under heavy development.
 
+* Apache2 handler is a joke and requires work.
+It can still serve requests though.
+
 Please report any bugs or feature requests to
 L<https://github.com/dallaylaen/perl-mvc-neaf/issues>.
 
@@ -995,9 +1069,15 @@ automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
+This is BETA software.
+Feel free to email the author to get instant help!
+Or you can comment the L<announce|http://perlmonks.org/?node_id=1174241>
+at the Perlmonks forum.
+
 You can find documentation for this module with the perldoc command.
 
     perldoc MVC::Neaf
+    perldoc MVC::Neaf::Request
 
 You can also look for information at:
 
@@ -1025,9 +1105,16 @@ L<http://search.cpan.org/dist/MVC-Neaf/>
 
 =back
 
+=head1 SEE ALSO
+
+The L<Kelp> framework has very similar concept.
 
 =head1 ACKNOWLEDGEMENTS
 
+Ideas were shamelessly stolen from L<Catalyst>, L<Dancer>, and L<PSGI>.
+
+Thanks to Eugene Ponizovsky aka L<IPH|https://metacpan.org/author/IPH>
+for introducing me to the MVC concept.
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -1039,7 +1126,6 @@ by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
-
 =cut
 
 1; # End of MVC::Neaf
