@@ -3,7 +3,7 @@ package MVC::Neaf::Request;
 use strict;
 use warnings;
 
-our $VERSION = 0.1001;
+our $VERSION = 0.11;
 
 =head1 NAME
 
@@ -363,13 +363,15 @@ sub form {
 Return a group of form parameters as a hashref.
 Only values that pass corresponding validation are added.
 
-B<EXPERIMANTAL>. API and naming subject to change.
+B<DEPRECATED>. Use L<MVC::Neaf::X::Form> instead.
 
 =cut
 
 sub get_form_as_hash {
     my ($self, %spec) = @_;
 
+    carp "DEPRECATED. get_form_as_hash() will be removed soon.";
+
     my %form;
     foreach (keys %spec) {
         my $value = $self->param( $_, $spec{$_}, undef );
@@ -386,14 +388,15 @@ sub get_form_as_hash {
 Return a group of form parameters as a list, in that order.
 Values that fail validation are returned as undef, unless default given.
 
-B<EXPERIMANTAL>. API and naming subject to change.
+B<DEPRECATED>. Use L<MVC::Neaf::X::Form> instead.
 
 =cut
 
 sub get_form_as_list {
     my ($self, $spec, @list) = @_;
 
-    # TODO Should we?
+    carp "DEPRECATED. get_form_as_list() will be removed soon.";
+
     $self->_croak( "Meaningless call in scalar context" )
         unless wantarray;
 
@@ -782,18 +785,16 @@ sub session {
     my ($self, $noinit) = @_;
 
     # agressive caching FTW
-    return $self->{session} if exists $self->{session};
+    return $self->{session} if exists $self->{session} or $noinit;
 
     if ($self->{session_engine}) {
         my $id = $self->get_cookie( $self->{session_cookie}, $self->{session_regex} );
         $self->{session} = $self->{session_engine}->load_session( $id )
             if $id;
-        $self->{session} ||= $self->{session_engine}->create_session
-            unless $noinit;
+        $self->{session} ||= $self->{session_engine}->create_session;
     } else {
         # TODO should we die if no engine?..
-        $self->{session} = {}
-            unless $noinit;
+        $self->{session} = {};
     };
     return $self->{session};
 };
